@@ -74,18 +74,18 @@ int32_t SPVM__Sys__Ioctl__ioctl(SPVM_ENV* env, SPVM_VALUE* stack) {
 #ifdef _WIN32
     
   if (items <= 2) {
-    return env->die(env, stack, "The $request_arg must be defined", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The $request_arg must be defined", __func__, FILE_NAME, __LINE__);
   }
   else {
     if (!obj_request_arg) {
-      return env->die(env, stack, "The $request_arg must be an Int object", FILE_NAME, __LINE__);
+      return env->die(env, stack, "The $request_arg must be an Int object", __func__, FILE_NAME, __LINE__);
     }
     else {
       int32_t request_arg_basic_type_id = env->get_object_basic_type_id(env, stack, obj_request_arg);
       int32_t request_arg_type_dimension = env->get_object_type_dimension(env, stack, obj_request_arg);
 
       if (request_arg_basic_type_id == SPVM_NATIVE_C_BASIC_TYPE_ID_INT_CLASS && request_arg_type_dimension == 0) {
-        int32_t request_arg_int32 = env->get_field_int_by_name(env, stack, obj_request_arg, "value", &e, FILE_NAME, __LINE__);
+        int32_t request_arg_int32 = env->get_field_int_by_name(env, stack, obj_request_arg, "value", &e, __func__, FILE_NAME, __LINE__);
         if (e) { return e; }
         
         u_long request_arg_u_long = (u_long)request_arg_int32;
@@ -94,11 +94,11 @@ int32_t SPVM__Sys__Ioctl__ioctl(SPVM_ENV* env, SPVM_VALUE* stack) {
         
         request_arg_int32 = (int32_t)request_arg_u_long;
 
-        env->set_field_int_by_name(env, stack, obj_request_arg, "value", request_arg_int32, &e, FILE_NAME, __LINE__);
+        env->set_field_int_by_name(env, stack, obj_request_arg, "value", request_arg_int32, &e, __func__, FILE_NAME, __LINE__);
         if (e) { return e; }
       }
       else {
-        return env->die(env, stack, "The $request_arg must be an Int object", FILE_NAME, __LINE__);
+        return env->die(env, stack, "The $request_arg must be an Int object", __func__, FILE_NAME, __LINE__);
       }
     }
   }
@@ -117,67 +117,67 @@ int32_t SPVM__Sys__Ioctl__ioctl(SPVM_ENV* env, SPVM_VALUE* stack) {
       int32_t request_arg_type_dimension = env->get_object_type_dimension(env, stack, obj_request_arg);
 
       if (!(request_arg_basic_type_id == SPVM_NATIVE_C_BASIC_TYPE_ID_INT_CLASS && request_arg_type_dimension == 0)) {
-        return env->die(env, stack, "The $request_arg must be an Int object on Windows", FILE_NAME, __LINE__);
+        return env->die(env, stack, "The $request_arg must be an Int object on Windows", __func__, FILE_NAME, __LINE__);
       }
       
       // Byte
       if (request_arg_basic_type_id == SPVM_NATIVE_C_BASIC_TYPE_ID_BYTE_CLASS && request_arg_type_dimension == 0) {
-        int8_t request_arg_int8 = env->get_field_byte_by_name(env, stack, obj_request_arg, "value", &e, FILE_NAME, __LINE__);
+        int8_t request_arg_int8 = env->get_field_byte_by_name(env, stack, obj_request_arg, "value", &e, __func__, FILE_NAME, __LINE__);
         if (e) { return e; }
         
         ret = ioctl(fd, request, &request_arg_int8);
 
-        env->set_field_byte_by_name(env, stack, obj_request_arg, "value", request_arg_int8, &e, FILE_NAME, __LINE__);
+        env->set_field_byte_by_name(env, stack, obj_request_arg, "value", request_arg_int8, &e, __func__, FILE_NAME, __LINE__);
         if (e) { return e; }
       }
       // Short
       else if (request_arg_basic_type_id == SPVM_NATIVE_C_BASIC_TYPE_ID_SHORT_CLASS && request_arg_type_dimension == 0) {
-        int16_t request_arg_int16 = env->get_field_short_by_name(env, stack, obj_request_arg, "value", &e, FILE_NAME, __LINE__);
+        int16_t request_arg_int16 = env->get_field_short_by_name(env, stack, obj_request_arg, "value", &e, __func__, FILE_NAME, __LINE__);
         if (e) { return e; }
         
         ret = ioctl(fd, request, &request_arg_int16);
 
-        env->set_field_short_by_name(env, stack, obj_request_arg, "value", request_arg_int16, &e, FILE_NAME, __LINE__);
+        env->set_field_short_by_name(env, stack, obj_request_arg, "value", request_arg_int16, &e, __func__, FILE_NAME, __LINE__);
         if (e) { return e; }
       }
       // Int
       else if (request_arg_basic_type_id == SPVM_NATIVE_C_BASIC_TYPE_ID_INT_CLASS && request_arg_type_dimension == 0) {
-        int32_t request_arg_int32 = env->get_field_int_by_name(env, stack, obj_request_arg, "value", &e, FILE_NAME, __LINE__);
+        int32_t request_arg_int32 = env->get_field_int_by_name(env, stack, obj_request_arg, "value", &e, __func__, FILE_NAME, __LINE__);
         if (e) { return e; }
         
         ret = ioctl(fd, request, &request_arg_int32);
 
-        env->set_field_int_by_name(env, stack, obj_request_arg, "value", request_arg_int32, &e, FILE_NAME, __LINE__);
+        env->set_field_int_by_name(env, stack, obj_request_arg, "value", request_arg_int32, &e, __func__, FILE_NAME, __LINE__);
         if (e) { return e; }
       }
       // Long
       else if (request_arg_basic_type_id == SPVM_NATIVE_C_BASIC_TYPE_ID_LONG_CLASS && request_arg_type_dimension == 0) {
-        int64_t request_arg_int64 = env->get_field_long_by_name(env, stack, obj_request_arg, "value", &e, FILE_NAME, __LINE__);
+        int64_t request_arg_int64 = env->get_field_long_by_name(env, stack, obj_request_arg, "value", &e, __func__, FILE_NAME, __LINE__);
         if (e) { return e; }
         
         ret = ioctl(fd, request, &request_arg_int64);
 
-        env->set_field_long_by_name(env, stack, obj_request_arg, "value", request_arg_int64, &e, FILE_NAME, __LINE__);
+        env->set_field_long_by_name(env, stack, obj_request_arg, "value", request_arg_int64, &e, __func__, FILE_NAME, __LINE__);
         if (e) { return e; }
       }
       // Float
       else if (request_arg_basic_type_id == SPVM_NATIVE_C_BASIC_TYPE_ID_FLOAT_CLASS && request_arg_type_dimension == 0) {
-        float request_arg_float = env->get_field_float_by_name(env, stack, obj_request_arg, "value", &e, FILE_NAME, __LINE__);
+        float request_arg_float = env->get_field_float_by_name(env, stack, obj_request_arg, "value", &e, __func__, FILE_NAME, __LINE__);
         if (e) { return e; }
         
         ret = ioctl(fd, request, &request_arg_float);
 
-        env->set_field_float_by_name(env, stack, obj_request_arg, "value", request_arg_float, &e, FILE_NAME, __LINE__);
+        env->set_field_float_by_name(env, stack, obj_request_arg, "value", request_arg_float, &e, __func__, FILE_NAME, __LINE__);
         if (e) { return e; }
       }
       // Double
       else if (request_arg_basic_type_id == SPVM_NATIVE_C_BASIC_TYPE_ID_DOUBLE_CLASS && request_arg_type_dimension == 0) {
-        double request_arg_double = env->get_field_double_by_name(env, stack, obj_request_arg, "value", &e, FILE_NAME, __LINE__);
+        double request_arg_double = env->get_field_double_by_name(env, stack, obj_request_arg, "value", &e, __func__, FILE_NAME, __LINE__);
         if (e) { return e; }
         
         ret = ioctl(fd, request, &request_arg_double);
 
-        env->set_field_double_by_name(env, stack, obj_request_arg, "value", request_arg_double, &e, FILE_NAME, __LINE__);
+        env->set_field_double_by_name(env, stack, obj_request_arg, "value", request_arg_double, &e, __func__, FILE_NAME, __LINE__);
         if (e) { return e; }
       }
       // A pointer class
@@ -186,7 +186,7 @@ int32_t SPVM__Sys__Ioctl__ioctl(SPVM_ENV* env, SPVM_VALUE* stack) {
         ret = ioctl(fd, request, request_arg);
       }
       else {
-        return env->die(env, stack, "The $request_arg must be an Byte/Short/Int/Long/Float/Double object or the object that is a pointer class", FILE_NAME, __LINE__);
+        return env->die(env, stack, "The $request_arg must be an Byte/Short/Int/Long/Float/Double object or the object that is a pointer class", __func__, FILE_NAME, __LINE__);
       }
     }
   }
@@ -194,7 +194,7 @@ int32_t SPVM__Sys__Ioctl__ioctl(SPVM_ENV* env, SPVM_VALUE* stack) {
 #endif
 
   if (ret == -1) {
-    env->die(env, stack, "[System Error]ioctl failed: %s", socket_strerror(env, stack, socket_errno(), 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]ioctl failed: %s", socket_strerror(env, stack, socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
 
