@@ -20,16 +20,16 @@ int32_t SPVM__Sys__Poll__PollfdArray__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t length = stack[0].ival;
   
   if (!(length >= 0)) {
-    return env->die(env, stack, "The length must be greater than or equal to 0", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The length must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
   
   struct pollfd* fds = env->new_memory_stack(env, stack, sizeof(struct pollfd) * length);
   
   int32_t fields_length = 1;
-  void* obj_self = env->new_pointer_by_name(env, stack, "Sys::Poll::PollfdArray", fds, &e, FILE_NAME, __LINE__);
+  void* obj_self = env->new_pointer_by_name(env, stack, "Sys::Poll::PollfdArray", fds, &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
   
-  env->set_field_int_by_name(env, stack, obj_self, "length", length, &e, FILE_NAME, __LINE__);
+  env->set_field_int_by_name(env, stack, obj_self, "length", length, &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   stack[0].oval = obj_self;
@@ -59,15 +59,15 @@ int32_t SPVM__Sys__Poll__PollfdArray__fd(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t index = stack[1].ival;
   
-  int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &e, FILE_NAME, __LINE__);
+  int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   if (!(index >= 0)) {
-    return env->die(env, stack, "The index must be greater than or equal to 0", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The index must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
   
   if (!(index < length)) {
-    return env->die(env, stack, "The index must be less than the length of the file descripters", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The index must be less than the length of the file descripters", __func__, FILE_NAME, __LINE__);
   }
 
   struct pollfd* fds = env->get_pointer(env, stack, obj_self);
@@ -87,15 +87,15 @@ int32_t SPVM__Sys__Poll__PollfdArray__set_fd(SPVM_ENV* env, SPVM_VALUE* stack) {
 
   int32_t index = stack[1].ival;
   
-  int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &e, FILE_NAME, __LINE__);
+  int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   if (!(index >= 0)) {
-    return env->die(env, stack, "The index must be greater than or equal to 0", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The index must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
   
   if (!(index < length)) {
-    return env->die(env, stack, "The index must be less than the length of the file descripters", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The index must be less than the length of the file descripters", __func__, FILE_NAME, __LINE__);
   }
 
   int32_t fd = stack[2].ival;
@@ -115,14 +115,14 @@ int32_t SPVM__Sys__Poll__PollfdArray__events(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t index = stack[1].ival;
   if (!(index >= 0)) {
-    return env->die(env, stack, "The index must be greater than or equal to 0", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The index must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
   
-  int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &e, FILE_NAME, __LINE__);
+  int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   if (!(index < length)) {
-    return env->die(env, stack, "The index must be less than the length of the file descripters", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The index must be less than the length of the file descripters", __func__, FILE_NAME, __LINE__);
   }
 
   struct pollfd* fds = env->get_pointer(env, stack, obj_self);
@@ -142,14 +142,14 @@ int32_t SPVM__Sys__Poll__PollfdArray__set_events(SPVM_ENV* env, SPVM_VALUE* stac
 
   int32_t index = stack[1].ival;
   if (!(index >= 0)) {
-    return env->die(env, stack, "The index must be greater than or equal to 0", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The index must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
   
-  int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &e, FILE_NAME, __LINE__);
+  int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   if (!(index < length)) {
-    return env->die(env, stack, "The index must be less than the length of the file descripters", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The index must be less than the length of the file descripters", __func__, FILE_NAME, __LINE__);
   }
 
   int16_t events = stack[2].ival;
@@ -169,13 +169,13 @@ int32_t SPVM__Sys__Poll__PollfdArray__revents(SPVM_ENV* env, SPVM_VALUE* stack)
   
   int32_t index = stack[1].ival;
   if (!(index >= 0)) {
-    return env->die(env, stack, "The index must be greater than or equal to 0", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The index must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
-  int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &e, FILE_NAME, __LINE__);
+  int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   if (!(index < length)) {
-    return env->die(env, stack, "The index must be less than the length of the file descripters", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The index must be less than the length of the file descripters", __func__, FILE_NAME, __LINE__);
   }
 
   struct pollfd* fds = env->get_pointer(env, stack, obj_self);
@@ -195,14 +195,14 @@ int32_t SPVM__Sys__Poll__PollfdArray__set_revents(SPVM_ENV* env, SPVM_VALUE* sta
 
   int32_t index = stack[1].ival;
   if (!(index >= 0)) {
-    return env->die(env, stack, "The index must be greater than or equal to 0", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The index must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
   
-  int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &e, FILE_NAME, __LINE__);
+  int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   if (!(index < length)) {
-    return env->die(env, stack, "The index must be less than the length of the file descripters", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The index must be less than the length of the file descripters", __func__, FILE_NAME, __LINE__);
   }
 
   int16_t revents = stack[2].ival;
